@@ -6,7 +6,7 @@ use Text::CSV_XS;
 use Scalar::Util qw( reftype );
 use List::Util qw( max );
 use Cwd;
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
@@ -156,8 +156,8 @@ incoming taxonomy file.
 =item * In the column designated as the "path" column, the same value is
 observed more than once.
 
-=item * C<id>, C<parent_id> and C<name> are reserved terms.  One or more columns is
-named with a reserved term.
+=item * C<id>, C<parent_id>, C<name>, C<lft> and C<rgh> are reserved terms.
+One or more columns is named with a reserved term.
 
 =item * A non-parent node's parent node cannot be located in the incoming taxonomy file.
 
@@ -267,11 +267,11 @@ sub _prepare_fields {
 
     my %fields_seen = map { $_ => 1 } @{$fields_ref};
     my @bad_fields = ();
-    for my $reserved ( qw| id parent_id name | ) {
+    for my $reserved ( qw| id parent_id name lft rgh | ) {
         push @bad_fields, $reserved if $fields_seen{$reserved};
     }
-    my $msg = "Bad column names: <@bad_fields>.  These are reserved for subroutine 'adjacentify()' ";
-    $msg .= "and for interaction with Parse::Taxonomy::AdjacentList; please rename";
+    my $msg = "Bad column names: <@bad_fields>.  These are reserved for ";
+    $msg .= "Parse::Taxonomy's internal use; please rename";
     croak $msg if @bad_fields;
 
     $data->{fields} = $fields_ref;
@@ -290,13 +290,19 @@ sub _check_path_col_idx {
 }
 
 sub _prepare_data_records {
+    # Confirm each row's path starts with path_col_sep:
     # Confirm no duplicate entries in column holding path:
     # Confirm all rows have same number of columns as header:
     my ($data, $data_records, $args) = @_;
+    my $error_msg;
+    my @bad_path_cols = ();
     my @bad_count_records = ();
     my %paths_seen = ();
     my $field_count = scalar(@{$data->{fields}});
     for my $rec (@{$data_records}) {
+        unless ($rec->[$data->{path_col_idx}] =~ m/^\Q$data->{path_col_sep}\E/) {
+            push @bad_path_cols, $rec->[$data->{path_col_idx}];
+        }
         $paths_seen{$rec->[$data->{path_col_idx}]}++;
         my $this_row_count = scalar(@{$rec});
         if ($this_row_count != $field_count) {
@@ -304,11 +310,20 @@ sub _prepare_data_records {
                 [ $rec->[$data->{path_col_idx}], $this_row_count ];
         }
     }
+    $error_msg = <<IMPROPER_PATH;
+The value of the column designated as path must start with the path column separator.
+Rows with the following paths fail to do so:
+IMPROPER_PATH
+    for my $path (@bad_path_cols) {
+        $error_msg .= "  $path\n";
+    }
+    croak $error_msg if @bad_path_cols;
+
     my @dupe_paths = ();
     for my $path (sort keys %paths_seen) {
         push @dupe_paths, $path if $paths_seen{$path} > 1;
     }
-    my $error_msg = <<ERROR_MSG_DUPE;
+    $error_msg = <<ERROR_MSG_DUPE;
 No duplicate entries are permitted in column designated as path.
 The following entries appear the number of times shown:
 ERROR_MSG_DUPE
